@@ -89,20 +89,67 @@ def li_import(slide_deck_pdf, tex_output_path=None, num_to_take=None, force=Fals
 
     # slide_deck_split_svg = slidedeck_to_images(slide_deck_pdf, svg_tmp_dir + "/" + svg_pfix + "-%i.svg",
     #                                            num_to_take=num_to_take)
-    slide_deck_split_svg = slidedeck_to_images(slide_deck_pdf, svg_tmp_dir+"/"+svg_pfix+"-%i.svg", num_to_take=num_to_take)
+    slide_deck_split_svg = slidedeck_to_images(slide_deck_pdf, svg_tmp_dir+"/"+svg_pfix+"-%i.pdf", num_to_take=num_to_take)
     print("Converting svg to osvg..")
     for i,osvg in enumerate(slide_deck_split_svg):
-        dosvg = raw_svg_to_osvg(osvg, overwrite_existing=True, height=svg_height, width=svg_width)
-        osvgs_basename.append(dosvg)
+        # # Really unclear if this one is a good idea.
+        # dosvg = raw_svg_to_osvg(osvg, overwrite_existing=True, height=svg_height, width=svg_width)
+        # osvgs_basename.append(dosvg)
+        f = os.path.relpath(osvg, os.path.dirname(tex_output_path))
 
+
+        osvgs_basename.append( (os.path.basename(osvg)[:-4], f[:-4]) )
+        # slide_deck_split_svg
+
+    import jinja2
+
+    from jinja2 import Environment
+
+    template = """
+{% for sf, file in osvgs_basename %}
+\\begin{frame}\osvg{{"{"}}{{sf}}{{"}"}}
+{% if include_figure %}
+\includegraphics[width=1.0\linewidth,height=\\textheight,keepaspectratio]{{"{"}}{{file}}{{"}"}}
+{% endif %}
+\end{frame}
+{% endfor %}
+    """
+    # \\begin{textblock}{1}(0,0)
+    # \end{textblock}
+    env = Environment()
+    t = env.from_string(template)
+    s = t.render(dict(osvgs_basename=osvgs_basename, include_figure=True))
     print("jinjafying and cleaning...")
+
     # osvgs_basename = osvgs_basename[3:] # Drop first 3 slides; automatically generated.
-    data = {'osvgs_basename' : osvgs_basename}
-    s = jinjafy_comment(data, jinja_tag="jinja1")
+    # data = {'osvgs_basename' : osvgs_basename}
+    # s = jinjafy_comment(data, jinja_tag="jinja1")
     with open(output_dir + "/%s"%svg_converted_slides, 'w') as f:
         f.write(s)
+    # Now run slider on this shit to get the osvg files.
+
+    from slider.slider_cli import slider_cli
+    slider_cli(latexfile=tex_output_path, interactive=False)
+    # slider_cli(tex_output, interactive=False)
+    with open(tex_output_path, 'r') as f:
+        s = f.read()
+    i = s.find("\\end{document}")
+    ss = s[:i] + "\\input{svg_converted_slides}" + s[i:]
+    with open(tex_output_path, 'w') as f:
+        f.write(ss)
+    # Convert to get the osvg files.
+    slider_cli(tex_output_path, interactive=False)
+
+    with open(output_dir + "/%s"%svg_converted_slides, 'w') as f:
+        f.write(t.render(dict(osvgs_basename=osvgs_basename, include_figure=False)))
+    # Convert a final time to remove the included files (optional)
+    # slider_cli(tex_output_path, interactive=False)
+    print("Conversion is all done, main tex file is", tex_output_path)
+    # Remove backgrounds and recompile.
+
     return lecture_tex_out
 
+
 # <jinja1>
 # {% for sf in osvgs_basename %}
 # \begin{frame}\osvg{{"{"}}{{sf}}{{"}"}}
@@ -334,8 +381,12 @@ def slidedeck_to_images(slide_deck_pdf, base_out_pattern, num_to_take=None):
     for i, opdf in enumerate(slide_deck_split_pdf):
         print("convertion", i, opdf)
         ofile = base_out_pattern %(i+1)
-        cmd = f"pdf2svg {opdf} {ofile}"
-        execute_command(cmd.split())
+        if ofile[-4:] == opdf[-4:]:
+            # Same extension, no conversion needed.
+            shutil.move(opdf, ofile)
+        else:
+            cmd = f"pdf2svg {opdf} {ofile}"
+            execute_command(cmd.split())
         b = os.path.getsize(ofile)
         # print(b)
         if b == 0:
